@@ -509,7 +509,7 @@ class Sf:
                 sfdf = pd.DataFrame()
                 for result in self.bulk.get_all_results_for_query_batch(batch):
                     result = json.load(IteratorBytesIO(result))
-                    sfdf = sfdf.append(pd.DataFrame(result))
+                    sfdf = pd.concat([sfdf, pd.DataFrame(result)])
 
                 # drops attributes column in dataframe
                 sfdf.drop(columns="attributes", inplace = True)
@@ -551,9 +551,16 @@ class Sf:
     ### Asynchronous Data Functions
     ### ----------------------------------------------------------------------------------------------------
 
-    async def async_query(self, query, excludedFields: Optional[List]= []) -> pd.DataFrame:
+    async def async_query(self, query) -> pd.DataFrame:
         async_query = async_wrap(self.query)
         return await async_query(query, excludedFields)
+    
+    async def async_queries(self, queries: List[str]):
+        async_queries = async_wrap(self.sf.query)
+        result_list = await asyncio.gather(*[async_queries(query) for query in queries])
+        result_pd_list = [transform_sf_result_set_rec(result['records']) for result in result_list]
+        return result_pd_list
+
 
     async def async_upsert(self, object_api, record_dataframe, external_id_field_api, batchsize=2000, *args, **kwargs):
         async_upsert = async_wrap(self.upsert)
@@ -854,7 +861,7 @@ class Sf:
             processing_df['CRM Object and Field API'] = processing_df.index.get_level_values(0)
             processing_df[['CRM Object API','CRM Field API']] = processing_df['CRM Object and Field API'].str.split(".", expand = True)
             processing_df.reset_index(drop=True, inplace=True)
-            output_df = output_df.append(processing_df)
+            output_df = pd.concat([output_df,processing_df])
         return output_df
 
     def picklist_dataframe(self,objects = ['Account','Address_vod__c','Child_Account_vod__c']) -> List:
